Module error

Library errors

Enums

GlueError
Errors that can be raised by the glue between this Rust library and the original libbtrfsutil C library.
LibError
Errors that can be raised by the libbtrfsutil C library itself.

Type Aliases

BtrfsUtilError
Generic library error type. If GlueErrors happen, they will panic.