Enum LibError

pub enum LibError {
Show 27 variants Ok = 0, StopIteration = 1, NoMemory = 2, InvalidArgument = 3, NotBtrfs = 4, NotSubvolume = 5, SubvolumeNotFound = 6, OpenFailed = 7, RmdirFailed = 8, UnlinkFailed = 9, StatFailed = 10, StatfsFailed = 11, SearchFailed = 12, InoLookupFailed = 13, SubvolGetflagsFailed = 14, SubvolSetflagsFailed = 15, SubvolCreateFailed = 16, SnapCreateFailed = 17, SnapDestroyFailed = 18, DefaultSubvolFailed = 19, SyncFailed = 20, StartSyncFailed = 21, WaitSyncFailed = 22, GetSubvolInfoFailed = 23, GetSubvolRootrefFailed = 24, InoLookupUserFailed = 25, FsInfoFailed = 26,
}
Errors that can be raised by the libbtrfsutil C library itself.

Variants



Ok = 0

Success



StopIteration = 1

Stop iteration



NoMemory = 2

Cannot allocate memory



InvalidArgument = 3

Invalid argument



NotBtrfs = 4

Not a Btrfs filesystem



NotSubvolume = 5

Not a Btrfs subvolume



SubvolumeNotFound = 6

Subvolume not found



OpenFailed = 7

Could not open



RmdirFailed = 8

Could nor rmdir



UnlinkFailed = 9

Could not unlink



StatFailed = 10

Could not stat



StatfsFailed = 11

Could not statfs



SearchFailed = 12

Could not search B-tree



InoLookupFailed = 13

Could not lookup inode



SubvolGetflagsFailed = 14

Could not get subvolume flags



SubvolSetflagsFailed = 15

Could not set subvolume flags



SubvolCreateFailed = 16

Could not create subvolume



SnapCreateFailed = 17

Could not create snapshot



SnapDestroyFailed = 18

Could not destroy subvolume/snapshot



DefaultSubvolFailed = 19

Could not set default subvolume



SyncFailed = 20

Could not sync filesystem



StartSyncFailed = 21

Could not start filesystem sync



WaitSyncFailed = 22

Could not wait for filesystem sync



GetSubvolInfoFailed = 23

Could not get subvolume information with BTRFS_IOC_GET_SUBVOL_INFO



GetSubvolRootrefFailed = 24

Could not get rootref information with BTRFS_IOC_GET_SUBVOL_ROOTREF



InoLookupUserFailed = 25

Could not resolve subvolume path with BTRFS_IOC_INO_LOOKUP_USER



FsInfoFailed = 26

Could not get filesystem information

Implementations

Source

impl LibError

pub fn strerror(&self) -> Result<&'static str>

Get the string description of a LibError, using the btrfs_util_strerror() function provided by libbtrfsutil.

LibError provides an std::fmt::Display implementation provided by thiserror. This function should not be the preferred mechanism for obtaining the error message.